/**
    Battery analyzer
    (c) 2016-2017 F. Štefanec
    This project is provided WITHOUT ANY WARRANTY, use at your own risk.
**/



#ifndef LCD_H_INCLUDED
#define LCD_H_INCLUDED

#include <avr/io.h>
#include <util/delay.h>
#include "config.h"


// command definition/name:  command value:  command description, command execution time:
#define LCD_INITSEQ             0b00110000 // initialization sequence
#define LCD_CLEAR               0b00000001 // display clear command, 5ms
#define LCD_HOME                0b00000010 // LCD return home command, 2ms
#define LCD_ENTRYMODE           0b00000100 // entry mode set command, 50us:
#define LCD_ENTRYMODE_INCREMENT 0b00000010 //   set: increment cursor position, not set: decrement cursor position
#define LCD_ENTRYMODE_SHIFT     0b00000001 //   set: display shift enabled
#define LCD_ONOFF               0b00001000 // on/off control, 50us
#define LCD_ONOFF_DISPLAY       0b00000100 //   set: display on
#define LCD_ONOFF_CURSOR        0b00000010 //   set: curson on
#define LCD_ONOFF_BLINK         0b00000001 //   set: cursor blinking
#define LCD_SHIFT               0b00010000 // LCD cursor/display shift control, 50us
#define LCD_SHIFT_DISPSHIFT     0b00001000 //   set: display shift, not set: cursor move
#define LCD_SHIFT_RIGHT         0b00000100 //   set: shift to the right, not set: shift to the left
#define LCD_FUNCSET             0b00100000 // display function set, 50us
#define LCD_FUNCSET_LEN8B       0b00010000 //   set: 8 bit bus, not set: 4 bit bus
#define LCD_FUNCSET_2LINES      0b00001000 //   set: 2+ line display, not set: single line display
#define LCD_FUNCSET_5X10DOTS    0b00000100 //   set: character size = 10x5, not set: character size = 8x5
#define LCD_SETCGADD            0b01000000 // set character generator ROM address, 50us
#define LCD_SETDDADD            0b10000000 // set display data RAM address, 50us

// function aliases
#define lcd_writedata()         lcd_rshigh()
#define lcd_writecmd()          lcd_rslow()


void pulse_e();
void lcd_send(uint8_t command);
void lcd_send4h(uint8_t command);
void lcd_init();
void lcd_rshigh();
void lcd_rslow();
void lcd_sendstring(char (*in_string), uint8_t len);
void lcd_setcursor(uint8_t column, uint8_t line);
void lcd_customchar(uint8_t addr, char *customchar);
void lcd_clear();
void lcd_printspaces(uint8_t len);

#endif
